Time-Series Data — GDA Toolbox v1.0 Manual

# Time-Series Data

If your data is parametrized by a single _time_ variable, then it is essentially one-dimensional. Data of this type are analyzed in the `timeseries` module.

There are two distinct but related cases:

> - The data is a plain function, \(\mathrbb{R} \to \mathbb{R}\). These are studied with the `timeseries.Signal` class.
> - The data is an embedded curve, \(\mathrbb{R} \to \mathbb{R}^d\). These are studied with the `timeseries.SpaceCurve` class.

Of course, each component of a `timeseries.SpaceCurve` could be analyzed as `timeserie.Signal`, and a `timeseries.Signal` can be thought of as a `timeseries.SpaceCurve` with \(d=1\). However, the geometric considerations are often quite different between a simple amplitude-versus-time signal, and a trajectory in space.

> `timeseries` | This module defines tools for geometric analysis of one-dimensional (time-series) data sets.
> `timeseries.Signal`(values[, times]) |
> `timeseries.SpaceCurve`(tn[, px, py, pz, …]) | SpaceCurve is a Python class for studying curves in \(\mathbb{R}^2\) or \(\mathbb{R}^3\).

#### Previous topic

multidim.Simplex.representative

#### Next topic

timeseries